@@ -1,5 +1,4 @@
 import os
-import io
 import hashlib
 import requests
 import tempfile
@@ -7,8 +6,10 @@ import mimetypes
 import numpy as np
 
 from PIL import Image
+from io import BytesIO
 from fnmatch import fnmatch
 from datetime import datetime
+
 from . import config
 
 
@@ -22,7 +23,7 @@ def file_path(f, userid):
 
 def md5sum(src):
     hash_md5 = hashlib.md5()
-    f = io.BytesIO(src.getvalue()) if isinstance(src, io.BytesIO) else open(src, 'rb')
+    f = BytesIO(src.getvalue()) if isinstance(src, BytesIO) else open(src, 'rb')
     for chunk in iter(lambda: f.read(4096), b''):
         hash_md5.update(chunk)
     f.close()
@@ -73,37 +74,32 @@ class Abraia:
             folders = list(filter(lambda f: fnmatch(f['path'], path), folders))
         return files, folders
 
-    def upload_remote(self, url, path):
-        json = {'url': url}
-        url = f"{API_URL}/files/{self.userid}/{path}"
-        resp = requests.post(url, json=json, auth=self.auth)
-        if resp.status_code != 201:
-            raise APIError(resp.text, resp.status_code)
-        resp = resp.json()
-        return file_path(resp['file'], self.userid)
-
     def upload_file(self, src, path=''):
-        if isinstance(src, str) and src.startswith('http'):
-            return self.upload_remote(src, path)
         if path == '' or path.endswith('/'):
             path = path + os.path.basename(src)
+        json = {}
         name = os.path.basename(path)
-        md5 = md5sum(src) # TODO: Refactor names to src, dest, path (cloud)
         type = mimetypes.guess_type(name)[0] or 'binary/octet-stream'
-        json = {'name': name, 'type': type, 'md5': md5} if md5 else {'name': name, 'type': type}
+        if isinstance(src, str) and src.startswith('http'):
+            json = {'url': src}
+        else:
+            json = {'name': name, 'type': type}
+            md5 = md5sum(src)
+            if md5:
+                json['md5'] = md5
         url = f"{API_URL}/files/{self.userid}/{path}"
-        print('>', url, json)
         resp = requests.post(url, json=json, auth=self.auth)
         if resp.status_code != 201:
             raise APIError(resp.text, resp.status_code)
         resp = resp.json()
         url = resp.get('uploadURL')
         if url:
-            data = src if isinstance(src, io.BytesIO) else open(src, 'rb')
+            data = src if isinstance(src, BytesIO) else open(src, 'rb')
             resp = requests.put(url, data=data, headers={'Content-Type': type})
             if resp.status_code != 200:
                 raise APIError(resp.text, resp.status_code)
-        return file_path({'name': name, 'source': f"{self.userid}/{path}"}, self.userid)
+            return file_path({'name': name, 'source': f"{self.userid}/{path}"}, self.userid)
+        return file_path(resp['file'], self.userid)
 
     def move_file(self, old_path, new_path):
         json = {'store': f"{self.userid}/{old_path}"}
@@ -119,11 +115,10 @@ class Abraia:
         resp = requests.get(url, stream=True, auth=self.auth)
         if resp.status_code != 200:
             raise APIError(resp.text, resp.status_code)
-        if dest:
-            with open(dest, 'wb') as f:
-                f.write(resp.content)
-            return dest
-        return io.BytesIO(resp.content)
+        if not dest:
+            return BytesIO(resp.content)
+        with open(dest, 'wb') as f:
+            f.write(resp.content)
 
     def remove_file(self, path):
         url = f"{API_URL}/files/{self.userid}/{path}"
@@ -174,11 +169,11 @@ class Abraia:
         return np.asarray(Image.open(stream))
 
     def save_file(self, path, stream):
-        stream =  io.BytesIO(bytes(stream, 'utf-8')) if isinstance(stream, str) else stream
+        stream =  BytesIO(bytes(stream, 'utf-8')) if isinstance(stream, str) else stream
         return self.upload_file(stream, path)
 
     def save_image(self, path, img):
-        # stream = io.BytesIO()
+        # stream = BytesIO()
         # mime = mimetypes.guess_type(path)[0]
         # format = mime.split('/')[1]
         # Image.fromarray(img).save(stream, format)
